@@ -8,11 +8,11 @@ use Plack::Request;
 use Plack::Response;
 use Plack::Session;
 use Plack::Util::Accessor qw(generator login_cb logo_image_url message_cb redirect_login redirect_error
-	register_link title);
+	register_link tags_after title);
 use Tags::HTML::Container;
-use Tags::HTML::Login::Access;
+use Tags::HTML::Login::Access 0.10;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub _css {
 	my ($self, $env) = @_;
@@ -46,6 +46,7 @@ sub _login_check {
 
 	return 1;
 }
+
 sub _message {
 	my ($self, $env, $message_type, $message) = @_;
 
@@ -82,6 +83,9 @@ sub _prepare_app {
 		%p,
 		'logo_image_url' => $self->logo_image_url,
 		'register_url' => $self->register_link,
+		defined $self->tags_after ? (
+			'tags_after' => $self->tags_after,
+		) : (),
 	);
 
 	$self->{'_container'} = Tags::HTML::Container->new(%p);
@@ -163,8 +167,6 @@ Plack::App::Login::Password - Plack login/password application.
 
 Constructor.
 
-Returns instance of object.
-
 =over 8
 
 =item * C<author>
@@ -181,15 +183,15 @@ Default value is 'text/html; charset=__ENCODING__'.
 
 =item * C<css>
 
-Instance of CSS::Struct::Output object.
+Instance of L<CSS::Struct::Output> object.
 
-Default value is CSS::Struct::Output::Raw instance.
+Default value is L<CSS::Struct::Output::Raw> instance.
 
 =item * C<css_init>
 
-Reference to array with CSS::Struct structure.
+Reference to array with L<CSS::Struct> structure.
 
-Default value is CSS initialization from Tags::HTML::Page::Begin like
+Default value is CSS initialization from L<Tags::HTML::Page::Begin> like
 
  * {
 	box-sizing: border-box;
@@ -293,7 +295,7 @@ Default value is 200.
 
 =item * C<tags>
 
-Instance of Tags::Output object.
+Instance of L<Tags::Output> object.
 
 Default value is
 
@@ -303,6 +305,12 @@ Default value is
          'preserved' => ['pre', 'style'],
  );
 
+=item * C<tags_after>
+
+Reference to array with L<Tags> code to use after form.
+
+Default value is undef.
+
 =item * C<title>
 
 Page title.
@@ -311,6 +319,8 @@ Default value is 'Login page'.
 
 =back
 
+Returns instance of object.
+
 =head2 C<call>
 
  my $psgi_ar = $obj->call($env);
@@ -484,12 +494,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2023 Michal Josef Špaček
+© 2023-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
